@@ -1,7 +1,7 @@
 import tensorflow as tf
 from einops import rearrange
 
-__all__ = ["TFDiceLoss"]
+__all__ = ["TFDiceLoss", "TFDiceCE"]
 
 BINARY_MODE = "binary"
 MULTICLASS_MODE = "multiclass"
